==> movie-13.11.2025.tar.gz: resources/views/agencies.blade.php <==
<?php
/**
 * @var $page[]
*/
?>
@extends('layouts.main')

@section('page-title',  'Агентства')
@section('keywords',    '')
@section('description', '')

@section('content')

    <div class="page-agency">
        <div class="page-agency--wrapp">
            <div class="bigCircle">
                <i class="circle"></i>
                <img src="/images/general/logo.svg" alt="" class="agency-logo">
                <p class="title">МЕДИА АНАЛИТИКА КОНСАЛТИНГ</p>
                <svg class="circle-diagramm" viewBox="0 0 700 700" xmlns="http://www.w3.org/2000/svg">
                    <circle class="circle-chart__circle success-stroke" stroke-dasharray="1" cx="350" cy="350" r="175"></circle>
                </svg>
                <div class="semicircle">
                    <img src="/images/general/logo2.svg" alt="" class="agency-logo">
                    <div class="title">ЦИФРОВЫЕ КОММУНИКАЦИИ</div>
                </div>
            </div>
            <div class="littleCircle">
                <i class="circle"></i>
                <img src="/images/general/logo3.svg" alt="" class="agency-logo">
                <p class="title">КРЕАТИВНЫЕ КОММУНИКАЦИИ</p>
            </div>
        </div>
        <div class="partnerBox">
            <svg style="width: 1195px; height: 1182px" class="svgPatern">
                <use xlink:href="#clienteleBt"></use>
            </svg>
            <a href="#" class="bt-partner"><span>ПАРТНЕРЫ</span></a>
            <div class="hideBox">
                <a href="http://www.skytecmedia.ru" class="item" target="_blank">
                    <svg class="circle-chart" viewBox="0 0 33.83098862 33.83098862" xmlns="http://www.w3.org/2000/svg">
                        <circle class="circle-chart__background" cx="16.9" cy="16.9" r="14.1"></circle>
                        <circle class="circle-chart__circle success-stroke" stroke-dasharray="67.8,100" cx="16.9" cy="16.9" r="14.1"></circle>
                    </svg>
                    <i class="circlePart"></i>
                    <img class="logoPart" src="/images/general/logo7.svg" alt="">
                </a>
                <a href="http://ignitionmedia.ru" class="item item2" target="_blank">
                    <svg class="circle-chart" viewBox="0 0 33.83098862 33.83098862" xmlns="http://www.w3.org/2000/svg">
                        <circle class="circle-chart__background" cx="16.9" cy="16.9" r="14.1"></circle>
                        <circle class="circle-chart__circle success-stroke" stroke-dasharray="67.8,100" cx="16.9" cy="16.9" r="14.1"></circle>
                    </svg>
                    <i class="circlePart"></i>
                    <img class="logoPart logoPart2" src="/images/general/logo5.svg" alt="">
                </a>
            </div>
        </div>
    </div>

@endsection

==> movie-20.11.2025.tar.gz: resources/views/agencies.blade.php <==
<?php
/**
 * @var $page[]
*/
?>
@extends('layouts.main')

@section('page-title',  'Партнеры')
@section('keywords',    '')
@section('description', '')

@section('content')

    <div class="page-agency">
        <div class="page-agency--wrapp">
            <div class="bigCircle">
                <i class="circle"></i>
                <img src="/images/general/logo.svg" alt="" class="agency-logo">
                <p class="title">МЕДИА АНАЛИТИКА КОНСАЛТИНГ</p>
                <svg class="circle-diagramm" viewBox="0 0 700 700" xmlns="http://www.w3.org/2000/svg">
                    <circle class="circle-chart__circle success-stroke" stroke-dasharray="1" cx="350" cy="350" r="175"></circle>
                </svg>
                <div class="semicircle">
                    <img src="/images/general/logo2.svg" alt="" class="agency-logo">
                    <div class="title">ЦИФРОВЫЕ КОММУНИКАЦИИ</div>
                </div>
            </div>
            <div class="littleCircle">
                <i class="circle"></i>
                <img src="/images/general/logo3.svg" alt="" class="agency-logo">
                <p class="title">КРЕАТИВНЫЕ КОММУНИКАЦИИ</p>
            </div>
            <div class="littleCircleLogo">
                <img class="agency-logo" src="/images/general/logo7.png" alt="">
                <!-- <p class="littleCircle-Text">№ 4 рейтинга медиаагентств 2025</p> -->
                <p class="littleCircle-Text"><a class="agency__descr-more" href="https://www.sostav.ru/ratings/mediarating2025" target="_blank">№ 4 рейтинга медиаагентств 2025</a></p>

            </div>
        </div>

        <div class="partnerBox" style="display: none;">
            <svg style="width: 1195px; height: 1182px" class="svgPatern">
                <use xlink:href="#clienteleBt"></use>
            </svg>
            <a href="#" class="bt-partner"><span>ПАРТНЕРЫ</span></a>
            <div class="hideBox">
                <a href="http://www.skytecmedia.ru" class="item" target="_blank">
                    <svg class="circle-chart" viewBox="0 0 33.83098862 33.83098862" xmlns="http://www.w3.org/2000/svg">
                        <circle class="circle-chart__background" cx="16.9" cy="16.9" r="14.1"></circle>
                        <circle class="circle-chart__circle success-stroke" stroke-dasharray="67.8,100" cx="16.9" cy="16.9" r="14.1"></circle>
                    </svg>
                    <i class="circlePart"></i>
                    <img class="logoPart" src="/images/general/logo7.svg" alt="">
                </a>
                <a href="http://ignitionmedia.ru" class="item item2" target="_blank">
                    <svg class="circle-chart" viewBox="0 0 33.83098862 33.83098862" xmlns="http://www.w3.org/2000/svg">
                        <circle class="circle-chart__background" cx="16.9" cy="16.9" r="14.1"></circle>
                        <circle class="circle-chart__circle success-stroke" stroke-dasharray="67.8,100" cx="16.9" cy="16.9" r="14.1"></circle>
                    </svg>
                    <i class="circlePart"></i>
                    <img class="logoPart logoPart2" src="/images/general/logo5.svg" alt="">
                </a>
            </div>
        </div>
    </div>

@endsection
